# Generated by roxygen2: do not edit by hand

export(EventCoverage)
export(FDRcutoff)
export(QC)
export(SVM)
export(Zeta)
export(ZetaSuitSC)
export(ZetaSuiteApp)
export(Zscore)
importFrom(DT,dataTableOutput)
importFrom(DT,datatable)
importFrom(DT,renderDataTable)
importFrom(RColorBrewer,brewer.pal)
importFrom(Rtsne,Rtsne)
importFrom(e1071,svm)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(mixtools,normalmixEM)
importFrom(plotly,ggplotly)
importFrom(reshape2,melt)
importFrom(shiny,a)
importFrom(shiny,actionButton)
importFrom(shiny,br)
importFrom(shiny,checkboxInput)
importFrom(shiny,code)
importFrom(shiny,downloadButton)
importFrom(shiny,fileInput)
importFrom(shiny,fluidRow)
importFrom(shiny,h3)
importFrom(shiny,h4)
importFrom(shiny,numericInput)
importFrom(shiny,observeEvent)
importFrom(shiny,p)
importFrom(shiny,plotOutput)
importFrom(shiny,reactiveValues)
importFrom(shiny,renderPlot)
importFrom(shiny,req)
importFrom(shiny,runApp)
importFrom(shiny,showNotification)
importFrom(shiny,tabPanel)
importFrom(shiny,tabsetPanel)
importFrom(shiny,tags)
importFrom(shiny,textOutput)
importFrom(shiny,verbatimTextOutput)
importFrom(shinydashboard,box)
importFrom(shinydashboard,dashboardHeader)
importFrom(shinydashboard,dashboardPage)
importFrom(shinydashboard,dashboardSidebar)
importFrom(shinydashboard,menuItem)
importFrom(shinydashboard,sidebarMenu)
importFrom(shinydashboard,tabItem)
importFrom(shinydashboard,tabItems)
importFrom(shinyjs,useShinyjs)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
